[java-opensaml COMMIT] /trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java

noreply at shibboleth.net noreply at shibboleth.net
Mon Nov 24 09:33:05 EST 2014


Author: scantor
Date: Mon Nov 24 09:33:05 2014
New Revision: 4165

URL: http://svn.shibboleth.net/view/java-opensaml?rev=4165&view=rev
Log:
Add a generic invalid message event.

Modified:
    trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java

Modified: trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java?rev=4165&r1=4164&r2=4165&view=diff
==============================================================================
--- trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java (original)
+++ trunk/opensaml-profile-api/src/main/java/org/opensaml/profile/action/EventIds.java Mon Nov 24 09:33:05 2014
@@ -39,7 +39,10 @@
      */
     @Nonnull @NotEmpty public static final String INVALID_MSG_CTX = "InvalidMessageContext";
 
-    /** ID of the event returned if a SAML message version is incorrect or unsupported. */
+    /** ID of the event returned if a message is invalid in some general way. */
+    @Nonnull @NotEmpty public static final String INVALID_MESSAGE = "InvalidMessage";
+
+    /** ID of the event returned if a message version is incorrect or unsupported. */
     @Nonnull @NotEmpty public static final String INVALID_MESSAGE_VERSION = "InvalidMessageVersion";
 
     /** ID of event returned if an error occurs with security configuration. */



More information about the commits mailing list